@@ -1,4 +1,5 @@
-from jsmin import JavascriptMinify
+from __future__ import absolute_import
+from .jsmin import JavascriptMinify
 from webassets.filter import Filter
 
 
@@ -16,4 +17,4 @@ class JSMinFilter(Filter):
     name = 'jsmin'
 
     def output(self, _in, out, **kw):
-        JavascriptMinify().minify(_in, out)
\ No newline at end of file
+        JavascriptMinify().minify(_in, out)
